@@ -121,7 +121,7 @@ def possessive_determiner(name, country_id=None, language_id=None):
 		- `country_id` -- Restrict name lookup for a specific country (*default:* `None`)
 		- `language_id` -- Restrict name lookup for a specific language (*default:* `None`)
 	"""
-	return 'his' if is_male(name=name, country_id=country_id, languate_id=language_id) else 'her'
+	return 'his' if is_male(name=name, country_id=country_id, language_id=language_id) else 'her'
 
 def female_probability(name, country_id=None, language_id=None, return_sample_size=False):
 	"""Return the probability of the given name being female
